# Terminis

Tetris clone for terminal. Ideal for servers without GUI!

## Requirements

[Python 2 or 3](https://www.python.org/)

beep command to play music with internal speaker

## Installation

```bash
pip install --user terminis
```

## Usage

```bash
terminis [options]
```

- --help -h: show command usage (this message)
- --edit -e: edit controls in text editor
- --reset -r: reset to default controls settings
- --level=n: start at level n (integer between 1 and 15)
